Description: North Dakota Supreme Court Opinions by month

August 2007
August 30, 2007
Lee v. Lee, 2007 ND 147
A trial court has subject matter jurisdiction to order a party to pay spousal support beyond the party's original spousal support obligation, even when the original obligation has already ended, when reconsideration of an interrelated child support obligation could constitute a change in circumstances for purposes of the spousal support obligation.
A change in a child support obligation may constitute a material change in circumstances requiring reconsideration of an interrelated spousal support obligation.
Attorney's fees will not be awarded absent a showing of need or a showing that an appeal was frivolous.
Peterson v. Dakota Molding, Inc., 2007 ND 144
In a garnishment proceeding, where a garnishee denies liability, the plaintiff may move the court for leave to file a supplemental complaint making the garnishee a party to the action, and setting forth the facts upon which the plaintiff claims to charge the garnishee. If probable cause is shown, the motion shall be granted.
The question whether probable cause has been shown, so as to require leave to file a supplemental complaint making a garnishee a party to an action, depends on whether the evidence shows probable grounds for believing that the garnishee might be held liable.
A term in an insurance policy should be construed to mean what a reasonable person in the position of the insured would think it meant. Limitations or exclusions from broad coverage must be clear and explicit. When the language of an insurance policy is clear and explicit, the language should not be strained in order to impose liability on the insurer.
State v. Demars, 2007 ND 145
Denial of a motion to suppress evidence will not be reversed if there is sufficient competent evidence capable of supporting the court's findings, and if its decision is not contrary to the manifest weight of the evidence.
State v. Kunze, 2007 ND 143
When a trial court concludes it is necessary to physically restrain a defendant at trial in front of the jury, the court must consider less restrictive, less prejudicial methods of restraint.
To provide for meaningful appellate review, a trial court must articulate its reasons for placing the defendant in physical restraints on the record, including a discussion of less prejudicial alternatives.
State v. Tibor, 2007 ND 146
A court does not abuse its discretion in allowing expert testimony about child sexual abuse accommodation syndrome if it finds the testimony may assist the jury in understanding the evidence or determine a fact in issue.
Mere repetition of a child's out-of-court statements does not make them unduly prejudicial.
A conviction rests upon insufficient evidence only when, after reviewing the evidence in the light most favorable to the prosecution and giving the prosecution the benefit of all inferences reasonably to be drawn in its favor, no rational fact-finder could find the defendant guilty beyond a reasonable doubt.
August 27, 2007
Tedford v. Workforce Safety and Insurance, 2007 ND 142
The retirement offset provision, N.D.C.C. 65-05-09.2, authorizing offset of social security retirement benefits against workers compensation disability benefits, does not apply to injured employees who were receiving benefits for a total disability prior to the statute's effective date.
In determining whether an administrative agency acted without substantial justification, triggering an award of actual attorney fees and costs under N.D.C.C. 28-32-50(1), the fact that a judge at an earlier stage of the proceedings agreed with the agency's position is persuasive evidence that the position was substantially justified.
August 24, 2007
Superior, Inc. v. Behlen Mfg., 2007 ND 141
A contractual right to indemnification may be implied based on the special nature of the relationship between the parties, or when there are unique factors demonstrating that the parties intended the would-be indemnitor to bear the ultimate responsibility for a certain matter.
Implied contractual indemnity is an equitable remedy that is available only if a party does not have an adequate remedy at law.
Under the Uniform Commercial Code, a buyer may seek consequential damages from the seller when it incurs liability to a third party as a result of the use or resale of the seller's product.
August 22, 2007
Burns v. Burns, 2007 ND 134
A continuance is the proper remedy for a party claiming surprise, and a judgment will not ordinarily be reversed on appeal for surprise when no request is made for a continuance at the time and there is no showing of inability to meet the situation.
If evidence of domestic violence does not rise to the level to trigger the presumption against an award of custody, the court may still consider the evidence as one of the best interest factors.
A district court's concerns about maintaining the custodial relationship that existed prior to the divorce and allowing the child to attend the same school and live in the same house are all valid considerations under N.D.C.C. 14-09-06.2(1)(d).
Being a child's primary caretaker does not guaranty a custody award in a divorce action.
City of Fargo v. Malme, 2007 ND 137
Cities are creatures of statute and possess only those powers and authorities granted by statute or necessarily implied from an express statutory grant.
Home rule charters allow cities to enact laws contrary to those of the state.
The supersession provision in N.D.C.C. 40-05.1-05 applies only to those powers enumerated in N.D.C.C. 40-05.1-06, and those powers must also be included in the home rule charter and be implemented by ordinance.
The rule of strict construction applies in defining municipal powers, and any doubt as to the existence or extent of municipal powers must be resolved against the municipality.
Estate of Allmaras, 2007 ND 130
A conservator has discretionary authority to manage the protected person's estate, subject to the conservator's fiduciary responsibilities and taking into account any known estate plan of the protected person.
A payable-on-death beneficiary has no present interest in the account, no right to prevent the depositor from removing the account funds and effectively destroying the beneficiary designation, and no right to preclude the depositor from changing or removing the beneficiaries on the account.
Farmers Union Mut. Ins. Co. v. Assoc. Electric and Gas Ins. Services Ltd., 2007 ND 135
Statutory interpretation is a question of law and fully reviewable on appeal.
Words in a statute are given their plain, ordinary, and commonly understood meaning, unless defined by statute or unless a contrary intention plainly appears.
Statutes are construed as a whole and are harmonized to give meaning to related provisions.
If the language of a statute is clear and unambiguous, the letter of the statute cannot be disregarded under the pretext of pursuing its spirit.
Under N.D.C.C. 26.1-41-17, which permits a basic no-fault insurer to seek equitable allocation and intercompany arbitration for no-fault benefits paid, "the motor vehicle liability insurer of a secured person" does not include an excess liability insurer.
Graner v. Graner, 2007 ND 139
A district court's decision on a custodial parent's motion to relocate out-of-state will be reversed on appeal only if it is clearly erroneous.
Increased visitation expenses and distance are not a sufficient basis to deny a custodial parent's motion to relocate.
A court may not modify custody within two years of an order establishing custody, unless the court finds the modification is in the child's best interests and there is willful denial of visitation, the child's environment endangers the child's physical or emotional health or impairs the child's emotional development, or the noncustodial parent has had primary physical care of the child for longer than six months.
J.P. v. Stark County Social Services, 2007 ND 140
When a medicaid recipient receives out-of-state medical care without prior approval when there is no emergency, payment may be covered only if there was good cause for not first securing approval, the care and services were not available in state, and the care and services were medically necessary.
Riemers v. State, 2007 ND App 4 - Court of Appeals
A judgment of dismissal for failure to state a claim upon which relief can be granted will be affirmed by an appellate court if it cannot discern a potential for proof to support the claim.
Under N.D.R.Civ.P. 12(c), if, on a motion for judgment on the pleadings, matters outside the pleadings are presented to and not excluded by the court, the motion must be treated as one for summary judgment under N.D.R.Civ.P. 56.
The court, in deciding a motion for judgment on the pleadings, may consider, in addition to the pleadings, materials embraced by the pleadings and materials that are part of the public record without converting the motion to a summary judgment.
State v. Kautzman, 2007 ND 133
A mistrial must be declared before the trial is over and before the jury has been discharged. When defense counsel moves for a mistrial, an instruction to the jury must be requested to properly preserve the question for appellate review.
A judgment of acquittal may be entered only if the evidence is insufficient to sustain a conviction.
For an offense to be a lesser included offense, it must be impossible to commit the greater offense without committing the lesser.
If counsel does not object to the trial court's instructions, the issue is not adequately preserved and inquiry on appeal is limited to whether the court's failure to instruct the jury was obvious error affecting substantial rights.
A party may not challenge as error a ruling or other trial proceeding invited by that party.
A trial court has broad discretion when deciding evidentiary matters, and its admission or exclusion of evidence will not be overturned on appeal unless that discretion has been abused.
State v. Muhle, 2007 ND 131
A court's evaluation of the trustworthiness of a child's out-of-court statement about alleged sexual abuse, may include these non-exclusive factors: (1) the spontaneity and consistent repetition of the statements, (2) the mental state of the declarant, (3) the use of terminology unexpected of a child of similar age, and (4) a lack of motive to fabricate.
If a defendant has an opportunity to cross-examine a witness at trial, the admission of testimonial statements would not violate the Confrontation Clause.
The proper remedy for unfair surprise is a continuance, but one must be requested.
The term "statement," as used in N.D.R.Crim.P. 16(f), means a written or otherwise recorded statement made by the witness, codefendant, or other person.
State v. Muhle, 2007 ND 132
A district court's evidentiary ruling is reviewed for an abuse of discretion.
Out-of-court testimonial statements may not be admitted into evidence when the child is unavailable to testify unless the defendant has had an opportunity to cross-examine the child. If a defendant has an opportunity to cross-examine the witness at trial, the admission of testimonial statements would not violate the Confrontation Clause.
Rule 16 of the North Dakota Rules of Criminal Procedure requires only "statements" be disclosed by the prosecution. "Statement" is defined technically and emphasizes formal, written, or recorded declarations.
To establish a violation under Brady v. Maryland, the defendant must prove: (1) the government possessed evidence favorable to the defendant; (2) the defendant did not possess the evidence and could not have obtained it with reasonable diligence; (3) the prosecution suppressed the evidence; and (4) a reasonable probability exists that the outcome of the proceedings would have been different if the evidence had been disclosed.
A conviction on the ground of insufficient evidence will be reversed only if, after viewing the evidence and all reasonable inferences in the light most favorable to the verdict, no rational factfinder could have found the defendant guilty beyond a reasonable doubt.
State v. Washington, 2007 ND 138
The probable cause standard is the same for both searches and arrests.
Once a vehicle has been validly stopped and its occupants lawfully detained, law enforcement officers may constitutionally order the driver and passengers out of the vehicle, even in situations not amounting to arrest.
Law enforcement officers have the right to use appropriate forcible means to effectuate an arrest.
An officer's subjective intent plays no role in ordinary probable cause Fourth Amendment analysis.
Stephenson v. Hoeven, 2007 ND 136
Statutes are construed as a whole to give meaning, if possible, to every word, phrase, and sentence.
An administrative agency may adopt specific rules of procedure when necessary to comply with requirements outside the administrative agencies practice act or when necessary to comply with the requirements of federal law.
August 16, 2007
Disciplinary Board v. Light, 2007 ND 129
Interim suspension of lawyer ordered.
August 15, 2007
Riemers v. State, 2007 ND App 3 - Court of Appeals
Factual assertions in a brief do not raise an issue of material fact satisfying Rule 56(e) for purposes of resisting a motion for summary judgment.
A party asserting a constitutional claim must do more than submit bare assertions and must bring up the heavy artillery or forego the claim.